  <img src="https://raw.githubusercontent.com/sijey-praveen/sijey-praveen/Profile/img/Python_logo_with_wordmark.png" height="40" width="140">

<h4>Supports Downloading : [favicon, image, gif, audio, video]</h4>

```python
from pywebmedia import PyWebMedia

PyWebMedia.download.image(url, file_name, format, save_location)

PyWebMedia.download.audio(url, file_name, format, save_location)

PyWebMedia.download.video(url, file_name, format, save_location)

PyWebMedia.download.favicon(domain, file_name, save_location)

PyWebMedia.download.gif(url, file_name , save_location)
```
